@@ -25,6 +25,7 @@
 
 #include <QString>
 
+#ifdef LIBZIP_COMPILED_WITH_32BIT_OFF_T
 //TODO:
 //a ninjatrick to redefine off_t to 32bit inside this file because libzip is
 //usually compiled with off_t to 32bit. in the long run libzip should be
@@ -33,6 +34,8 @@
 #define __off_t_defined
 typedef quint32 off_t;
 
+#endif /* LIBZIP_COMPILED_WITH_32BIT_OFF_T */
+
 #include "kerfuffle/archiveinterface.h"
 #include "kerfuffle/archivefactory.h"
 
