@@ -1,34 +1,26 @@
 /*
-** zip.cpp
-**
-** Copyright (C) 2002 by Adriaan de Groot
-**
-** This file defines the ZipFormat class, a DiskFormat
-** for KFloppy that deals with Zip disks and UFS under
-** FreeBSD (and probably other BSD's, as well).
+    
+    This file is part of the KFloppy program, part of the KDE project
+  
+    Copyright (C) 2002 by Adriaan de Groot
+  
+  
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+  
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+  
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+  
 */
 
-/*
-**
-**  This program is free software; you can redistribute it and/or modify
-**  it under the terms of the GNU General Public License as published by
-**  the Free Software Foundation; either version 2 of the License, or
-**  (at your option) any later version.
-**
-**  This program is distributed in the hope that it will be useful,
-**  but WITHOUT ANY WARRANTY; without even the implied warranty of
-**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-**  GNU General Public License for more details.
-**
-**  You should have received a copy of the GNU General Public License
-**  along with this program; if not, write to the Free Software
-**  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-**
-*/
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 #include <sys/types.h>
 #include <signal.h>
 
@@ -38,13 +30,12 @@
 #include "debug.h"
 #include "zip.moc"
 
-#include <qcheckbox.h>
-#include <qlayout.h>
-#include <qtimer.h>
-#include <qwhatsthis.h>
+#include <QCheckBox>
+#include <QTimer>
+#include <QGridLayout>
 
 #include <klocale.h>
-#include <kprocess.h>
+#include <k3process.h>
 #include <kconfig.h>
 
 ZipFormat::ZipFormat(QWidget *w,const char *n) :
@@ -56,10 +47,11 @@ ZipFormat::ZipFormat(QWidget *w,const char *n) :
 {
 	DEBUGSETUP;
 
-	QGridLayout *grid = new QGridLayout(this,1,1,10);
+	QGridLayout *grid = new QGridLayout(this);
+	grid->setSpacing(10);
 
 	zeroWholeDisk = new QCheckBox(i18n("Zero entire disk"),this);
-	QWhatsThis::add(zeroWholeDisk,
+	zeroWholeDisk->setWhatsThis(
 		i18n("Try to write zeroes to the entire disk "
 			"before adding a filesystem, in order "
 			"to check the disk's integrity."));
@@ -71,7 +63,7 @@ ZipFormat::ZipFormat(QWidget *w,const char *n) :
 	// up layour problems when this widget is smaller
 	// than others in the stack.
 	//
-	grid->addRowSpacing(2,10);
+	grid->addItem( new QSpacerItem( 0,10), 2, 0 );
 	grid->setRowStretch(2,100);
 
 	endInit();
@@ -123,8 +115,8 @@ FilesystemList ZipFormat::FSLabels() const
 void ZipFormat::quit()
 {
 	DEBUGSETUP;
-	if (p) delete p;
-	if (statusTimer) delete statusTimer;
+	delete p;
+	delete statusTimer;
 
 	p=0L;
 	statusTimer=0L;
@@ -143,17 +135,17 @@ void ZipFormat::quit()
 	formatStep=0;
 
 	if (p) delete p;
-	p = new KProcess();
+	p = new K3Process();
 
 	if (statusTimer) delete statusTimer;
 	statusTimer = new QTimer(this);
 
-	connect(p,SIGNAL(processExited(KProcess *)),
+	connect(p,SIGNAL(processExited(K3Process *)),
 		this,SLOT(transition()));
-	connect(p,SIGNAL(receivedStdout(KProcess *,char *,int)),
-		this,SLOT(processResult(KProcess *,char *,int)));
-	connect(p,SIGNAL(receivedStderr(KProcess *,char *,int)),
-		this,SLOT(processResult(KProcess *,char *,int)));
+	connect(p,SIGNAL(receivedStdout(K3Process *,char *,int)),
+		this,SLOT(processResult(K3Process *,char *,int)));
+	connect(p,SIGNAL(receivedStderr(K3Process *,char *,int)),
+		this,SLOT(processResult(K3Process *,char *,int)));
 	connect(statusTimer,SIGNAL(timeout()),
 		this,SLOT(statusRequest()));
 
@@ -194,7 +186,7 @@ void ZipFormat::transition()
 			<< "of=/dev/afd0c"
 			<< "bs=8192" ;
 		*p << QString("count=%1").arg(totalBlocks);
-		if (!p->start(KProcess::NotifyOnExit,KProcess::AllOutput))
+		if (!p->start(K3Process::NotifyOnExit,K3Process::AllOutput))
 		{
 			emit statusMessage(i18n("Cannot start dd to zero disk."));
 			emit formatDone(-1);
@@ -227,7 +219,7 @@ void ZipFormat::transition()
 			*p << "-U" ;
 		}
 		*p << "/dev/afd0c" ;
-		if (!p->start(KProcess::NotifyOnExit,KProcess::AllOutput))
+		if (!p->start(K3Process::NotifyOnExit,K3Process::AllOutput))
 		{
 			emit statusMessage(i18n("Cannot start newfs."));
 			emit formatDone(-1);
@@ -250,7 +242,7 @@ void ZipFormat::transition()
 	}
 }
 
-void ZipFormat::processResult(KProcess *, char *b, int l)
+void ZipFormat::processResult(K3Process *, char *b, int l)
 {
 	DEBUGSETUP;
 
@@ -268,9 +260,9 @@ void ZipFormat::processResult(KProcess *, char *b, int l)
 			emit setProgress(currentblock*100/totalBlocks);
 			if (totalBlocks>10000)
 			{
-				emit statusMessage(i18n("Zeroing block %1 of %2...")
-					.arg(currentblock)
-					.arg(totalBlocks));
+				emit statusMessage(i18n("Zeroing block %1 of %2...",
+					 currentblock,
+					 totalBlocks));
 			}
 		}
 		break;
