@@ -155,7 +155,7 @@ void MyView::clipEncrypt()
 
             if (!dialog->getCustomOptions().isEmpty())
                 if (KGpgSettings::allowCustomEncryptionOptions())
-                    options << dialog->getCustomOptions().split(" ", QString::SkipEmptyParts);
+                    options << dialog->getCustomOptions().split(' ', QString::SkipEmptyParts);
 
             encryptClipboard(dialog->selectedKeys(), options, dialog->getSymmetric());
         }
@@ -336,14 +336,14 @@ void MyView::slotFolderFinished(const KUrl &, KGpgTextInterface *iface)
 {
     delete pop;
     delete kgpgfoldertmp;
-    delete iface;
+    iface->deleteLater();
 }
 
 void MyView::slotFolderFinishedError(const QString &errmsge, KGpgTextInterface *iface)
 {
     delete pop;
     delete kgpgfoldertmp;
-    delete iface;
+    iface->deleteLater();
     KMessageBox::sorry(0, errmsge);
 }
 
@@ -380,7 +380,7 @@ void MyView::slotVerifyFile()
     if (droppedUrl.isEmpty())
         return;
 
-    QString sigfile = QString();
+    QString sigfile;
     // try to find detached signature.
     if (!droppedUrl.fileName().endsWith(".sig"))
     {
@@ -509,11 +509,11 @@ void MyView::decryptNextFile(KgpgLibrary *lib, const KUrl &failed)
 		droppedUrls.pop_front();
 		decryptFile(lib);
 	} else if ((droppedUrls.count() <= 1) && (m_decryptionFailed.count() > 0)) {
-		delete lib;
+		lib->deleteLater();
 		// FIXME: introduce better error message when string freeze is lifted
 		KMessageBox::errorList(NULL, i18n("Decryption failed."), m_decryptionFailed.toStringList(), i18n("Decryption failed."));
 	} else {
-		delete lib;
+		lib->deleteLater();
 	}
 }
 
@@ -748,7 +748,7 @@ int MyView::startWizard()
     wiz->kURLRequester2->setURL(KGlobalSettings::desktopPath());
         wiz->kURLRequester2->setMode(2);*/
 
-    QString firstKey = QString();
+    QString firstKey;
 
     KgpgInterface *interface = new KgpgInterface();
     KgpgKeyList secretlist = interface->readSecretKeys();
@@ -769,7 +769,7 @@ int MyView::startWizard()
     wiz->CBdefault->setCurrentItem(firstKey);
 
     //connect(wiz->pushButton4,SIGNAL(clicked()),this,SLOT(slotGenKey()));
-    if (!firstKey.isEmpty())
+    if (firstKey.isEmpty())
         connect(wiz->finishButton(),SIGNAL(clicked()),this,SLOT(slotGenKey()));
     else
     {
@@ -827,7 +827,7 @@ void MyView::slotSaveOptionsPath()
 
     KGpgSettings::self()->writeConfig();
     emit updateDefault(defaultID);
-    delete wiz;
+    wiz->deleteLater();
 }
 
 void MyView::slotWizardClose()
@@ -1064,10 +1064,8 @@ int KgpgAppletApp::newInstance()
     if (args->isSet("k") != 0)
     {
         s_keyManager->show();
-#ifdef Q_OS_UNIX
         KWindowSystem::setOnDesktop(s_keyManager->winId(), KWindowSystem::currentDesktop());  //set on the current desktop
         KWindowSystem::unminimizeWindow(s_keyManager->winId());  //de-iconify window
-#endif
         s_keyManager->raise();  // set on top
     }
     else
